SystemOrganization addCategory: #'Seaside-Tests-REST-Core'!

TestCase subclass: #WAByMethodRoutesTest
	instanceVariableNames: 'routes'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-REST-Core'!

!WAByMethodRoutesTest methodsFor: 'private' stamp: 'pmm 9/9/2009 19:23'!
assertMethod: aMethodString selector: aSymbol path: aFirstCollectionOfStrings arguments: aSecondCollectionOfStrings
	self
		assertMethod: aMethodString
		selector: aSymbol
		path: aFirstCollectionOfStrings
		parameters: Dictionary new
		arguments: aSecondCollectionOfStrings! !

!WAByMethodRoutesTest methodsFor: 'private' stamp: 'pmm 9/9/2009 19:26'!
assertMethod: aMethodString selector: aSymbol path: aFirstCollectionOfStrings parameters: aDictionary arguments: aSecondCollectionOfStrings
	| result stub |
	result := routes
		routeForMethod: aMethodString
		consumer: (WAPathConsumer path: aFirstCollectionOfStrings asOrderedCollection)
		parameters: aDictionary
		ifAbsent: [ self assert: false ].
	stub := WAByMethodRoutesStub new.
	result sendMessageTo: stub.
	self assert: stub selector = aSymbol.
	self assert: stub arguments = aSecondCollectionOfStrings! !

!WAByMethodRoutesTest methodsFor: 'private' stamp: 'pmm 9/9/2009 19:15'!
createRoutes
	^OrderedCollection new
		"Meta"
		add: (WARoute get: #getInfo);
		add: (WARoute get: '/_all_dbs' selector: #getAllDatabases);
		add: (WARoute get: '/_config' selector: #getConfig);
		add: (WARoute get: '/_stats' selector: #getStats);
		add: (WARoute get: '/_uuids?count={1}' selector: #getUuids:);
		add: (WARoute post: '/_replicate' selector: #replicate);
		
		"Database"
		add: (WARoute post: '/{1}/_compact' selector: #compactDatabase:);
		add: (WARoute put: #createDatabase:);
		add: (WARoute delete: #deleteDatabase:);
		add: (WARoute get: #getDatabase:);
		
		"Documents"
		add: (WARoute get: '/{1}/_all_docs' selector: #getAllDocuments:);
		add: (WARoute get: '/{2}/{1}' selector: #getDocument:ofDatabase:);
		add: (WARoute post: #createNewDocumentInDatabase:);
		add: (WARoute put: '/{2}/{1}' selector: #createOrUpdateDocument:inDatabase:);
		add: (WARoute delete: '/{2}/{1}' selector: #deleteDocument:inDatabase:);
		add: (WARoute post: '/{1}/_bulk_docs' selector: #createBulkDocumentsInDatabase:);
		add: (WARoute post: '/{1}/_temp_view' selector: #queryDatabase:);
		add: (WARoute get: '/{3}/_design/{2}/_view/{1}' selector: #getView:inDesign:inDatabase:);
		yourself! !

!WAByMethodRoutesTest methodsFor: 'running' stamp: 'pmm 9/9/2009 19:05'!
setUp
	super setUp.
	routes := WAByMethodRoutes routes: self createRoutes! !

!WAByMethodRoutesTest methodsFor: 'testing' stamp: 'pmm 9/9/2009 19:17'!
testCompactDatabase
	self
		assertMethod: 'POST'
		selector: #compactDatabase:
		path: #('credit_cards' '_compact')
		arguments: #('credit_cards')! !

!WAByMethodRoutesTest methodsFor: 'testing' stamp: 'pmm 9/9/2009 19:21'!
testCreateBulkDocumentsInDatabase
	self
		assertMethod: 'POST'
		selector: #createBulkDocumentsInDatabase:
		path: #('credit_cards' '_bulk_docs')
		arguments: #('credit_cards')! !

!WAByMethodRoutesTest methodsFor: 'testing' stamp: 'pmm 9/9/2009 19:17'!
testCreateDatabase
	self
		assertMethod: 'PUT'
		selector: #createDatabase:
		path: #('credit_cards')
		arguments: #('credit_cards')! !

!WAByMethodRoutesTest methodsFor: 'testing' stamp: 'pmm 9/9/2009 19:19'!
testCreateNewDocumentInDatabase
	self
		assertMethod: 'POST'
		selector: #createNewDocumentInDatabase:
		path: #('credit_cards')
		arguments: #('credit_cards')! !

!WAByMethodRoutesTest methodsFor: 'testing' stamp: 'pmm 9/9/2009 19:20'!
testCreateOrUpdateDocumentinDatabase
	self
		assertMethod: 'PUT'
		selector: #createOrUpdateDocument:inDatabase:
		path: #('credit_cards' '1111-2222-3333-4444')
		arguments: #('1111-2222-3333-4444' 'credit_cards')! !

!WAByMethodRoutesTest methodsFor: 'testing' stamp: 'pmm 9/9/2009 19:17'!
testDeleteDatabase
	self
		assertMethod: 'DELETE'
		selector: #deleteDatabase:
		path: #('credit_cards')
		arguments: #('credit_cards')! !

!WAByMethodRoutesTest methodsFor: 'testing' stamp: 'pmm 9/9/2009 19:20'!
testDeleteDocumentInDatabase
	self
		assertMethod: 'DELETE'
		selector: #deleteDocument:inDatabase:
		path: #('credit_cards' '1111-2222-3333-4444')
		arguments: #('1111-2222-3333-4444' 'credit_cards')! !

!WAByMethodRoutesTest methodsFor: 'testing' stamp: 'pmm 9/9/2009 19:10'!
testGetAllDatabases
	self
		assertMethod: 'GET'
		selector: #getAllDatabases
		path: #('_all_dbs')
		arguments: #()! !

!WAByMethodRoutesTest methodsFor: 'testing' stamp: 'pmm 9/9/2009 19:11'!
testGetConfig
	self
		assertMethod: 'GET'
		selector: #getConfig
		path: #('_config')
		arguments: #()! !

!WAByMethodRoutesTest methodsFor: 'testing' stamp: 'pmm 9/9/2009 19:13'!
testGetDatabase
	self
		assertMethod: 'GET'
		selector: #getDatabase:
		path: #('credit_cards')
		arguments: #('credit_cards')! !

!WAByMethodRoutesTest methodsFor: 'testing' stamp: 'pmm 9/9/2009 19:16'!
testGetDocumentOfDatabase
	self
		assertMethod: 'GET'
		selector: #getDocument:ofDatabase:
		path: #('credit_cards' '1111-2222-3333-4444')
		arguments: #('1111-2222-3333-4444' 'credit_cards')! !

!WAByMethodRoutesTest methodsFor: 'testing' stamp: 'pmm 9/9/2009 19:10'!
testGetInfo
	self
		assertMethod: 'GET'
		selector: #getInfo
		path: #()
		arguments: #()! !

!WAByMethodRoutesTest methodsFor: 'testing' stamp: 'pmm 9/9/2009 19:11'!
testGetStats
	self
		assertMethod: 'GET'
		selector: #getStats
		path: #('_stats')
		arguments: #()! !

!WAByMethodRoutesTest methodsFor: 'testing' stamp: 'pmm 9/9/2009 19:25'!
testGetUuids
	self
		assertMethod: 'GET'
		selector: #getUuids:
		path: #('_uuids')
		parameters: (Dictionary new
			at: 'count' put: '100';
			yourself)
		arguments: #('100')! !

!WAByMethodRoutesTest methodsFor: 'testing' stamp: 'pmm 9/9/2009 19:23'!
testGetViewInDesignInDatabase
	self
		assertMethod: 'GET'
		selector: #getView:inDesign:inDatabase:
		path: #('credit_cards' '_design' 'fraud' '_view' 'recent')
		arguments: #('recent' 'fraud' 'credit_cards')! !

!WAByMethodRoutesTest methodsFor: 'testing' stamp: 'pmm 9/9/2009 19:21'!
testQueryDatabase
	self
		assertMethod: 'POST'
		selector: #queryDatabase:
		path: #('credit_cards' '_temp_view')
		arguments: #('credit_cards')! !

!WAByMethodRoutesTest methodsFor: 'testing' stamp: 'pmm 9/9/2009 19:16'!
testReplicate
	self
		assertMethod: 'POST'
		selector: #replicate
		path: #('_replicate')
		arguments: #()! !

TestCase subclass: #WAComplexRouteTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-REST-Core'!

!WAComplexRouteTest methodsFor: 'testing' stamp: 'pmm 9/6/2009 23:30'!
testInstantiation
	WAUrl absolute: '/{3}/_all_docs?startkey={1}&limit={2}'! !

!WAComplexRouteTest methodsFor: 'testing' stamp: 'pmm 9/8/2009 17:20'!
testParameterMatchingMixedParameters
	| route parameters |
	route := WARoute get: '/{1}/_all_docs?rev={2}&uuids=true' selector: #a:b:.
	self deny: (route matchesParameters: Dictionary new).
	parameters := Dictionary new at: 'rev' put: '5'; yourself.
	self deny: (route matchesParameters: parameters).
	parameters at: 'uuids' put: 'true'.
	self assert: (route matchesParameters: parameters).
	parameters at: 'phpsessionid' put: '32432'.
	self deny: (route matchesParameters: Dictionary new).
	parameters removeKey: 'phpsessionid'.
	self assert: (route matchesParameters: parameters).
	parameters at: 'uuids' put: 'false'.
	self deny: (route matchesParameters: parameters).! !

!WAComplexRouteTest methodsFor: 'testing' stamp: 'pmm 9/8/2009 17:17'!
testParameterMatchingNoParameters
	| route parameters |
	route := WARoute get: '/{1}/_all_docs' selector: #a:.
	self assert: (route matchesParameters: Dictionary new).
	parameters := Dictionary new at: 'key' put: 'value'; yourself.
	self deny: (route matchesParameters: parameters)! !

!WAComplexRouteTest methodsFor: 'testing' stamp: 'pmm 6/26/2010 17:54'!
testPathMatching
	| route |
	route := WARoute get: '/{1}/_all_docs' selector: #a:.
	self deny: (route matchesPath: #('something')).
	self assert: (route matchesPath: #('something' '_all_docs')).
	self deny: (route matchesPath: #('something' 'else')).
	self deny: (route matchesPath: #('something' '_all_docs' 'more')).
	self assert: (route priority = 4).! !

TestCase subclass: #WAExactParameterMatchTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-REST-Core'!

!WAExactParameterMatchTest methodsFor: 'testing' stamp: 'pmm 6/13/2010 09:54'!
testInstantiation
	| match |
	match := WAParameterMatch name: 'rev' value: '58692' arguments: #().
	self assert: (match isKindOf: WAExactParameterMatch)! !

!WAExactParameterMatchTest methodsFor: 'testing' stamp: 'pmm 6/13/2010 09:54'!
testMatches
	| match |
	match := WAParameterMatch name: 'rev' value: '58692' arguments: #().
	self assert: (match matchesName: 'rev' value: '58692').
	self deny: (match matchesName: 'rev' value: 58692).
	self deny: (match matchesName: 'rev' value: 'a').
	self deny: (match matchesName: 'revision' value: '58692').! !

TestCase subclass: #WAExactPathMatchTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-REST-Core'!

!WAExactPathMatchTest methodsFor: 'testing' stamp: 'pmm 6/26/2010 17:52'!
testInstantiation
	| match |
	match := WAPPathMatch fromString: 'path' index: 1 arguments: #().
	self assert: (match isKindOf: WAExactPathMatch).
	self assert: match priority = 3.! !

!WAExactPathMatchTest methodsFor: 'testing' stamp: 'pmm 6/13/2010 09:31'!
testMatches
	| match |
	match := WAPPathMatch fromString: 'path' index: 1 arguments: #().
	self assert: (match matches: 'path').
	self deny: (match matches: 'poth')! !

TestCase subclass: #WAFullMimeTypeMatchTest
	instanceVariableNames: 'match'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-REST-Core'!

!WAFullMimeTypeMatchTest methodsFor: 'running' stamp: 'pmm 10/6/2010 12:45'!
setUp
	match := WAFullMimeTypeMatch main: 'application' sub: 'xml'! !

!WAFullMimeTypeMatchTest methodsFor: 'testing' stamp: 'pmm 10/6/2010 12:45'!
testMatches
	self assert: (match matches: (WAMimeType main: 'application' sub: 'xml')).
	self deny: (match matches: (WAMimeType main: 'something' sub: 'xml')).
	self deny: (match matches: (WAMimeType main: 'application' sub: 'something')).
	self deny: (match matches: (WAMimeType main: 'something' sub: 'something')).
	
	self assert: (match matches: (WAMimeType main: '*' sub: 'xml')).
	self assert: (match matches: (WAMimeType main: 'application' sub: '*')).
	self assert: (match matches: (WAMimeType main: '*' sub: '*')).
	
	self deny: (match matches: (WAMimeType main: 'something' sub: '*')).
	self deny: (match matches: (WAMimeType main: '*' sub: 'something'))! !

!WAFullMimeTypeMatchTest methodsFor: 'testing' stamp: 'pmm 10/6/2010 12:45'!
testPriority
	self assert: match priority = 3! !

TestCase subclass: #WAMainMimeTypeMatchTest
	instanceVariableNames: 'match'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-REST-Core'!

!WAMainMimeTypeMatchTest methodsFor: 'running' stamp: 'pmm 10/6/2010 12:46'!
setUp
	match := WAMainMimeTypeMatch main: 'application'! !

!WAMainMimeTypeMatchTest methodsFor: 'testing' stamp: 'pmm 10/6/2010 12:46'!
testMatches
	self assert: (match matches: (WAMimeType main: 'application' sub: 'xml')).
	self deny: (match matches: (WAMimeType main: 'something' sub: 'xml')).
	self assert: (match matches: (WAMimeType main: 'application' sub: 'something')).
	self deny: (match matches: (WAMimeType main: 'something' sub: 'something')).
	
	self assert: (match matches: (WAMimeType main: '*' sub: 'xml')).
	self assert: (match matches: (WAMimeType main: 'application' sub: '*')).
	self assert: (match matches: (WAMimeType main: '*' sub: '*')).
	
	self deny: (match matches: (WAMimeType main: 'something' sub: '*')).
	self assert: (match matches: (WAMimeType main: '*' sub: 'something'))! !

!WAMainMimeTypeMatchTest methodsFor: 'testing' stamp: 'pmm 10/6/2010 12:46'!
testPriority
	self assert: match priority = 2! !

TestCase subclass: #WAMimeTypeMatchTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-REST-Core'!

!WAMimeTypeMatchTest methodsFor: 'testing' stamp: 'pmm 10/6/2010 11:59'!
testFromMimeType
	| mimeType |
	mimeType := WAMimeTypeMatch fromMimeType: (WAMimeType fromString: 'application/xml').
	self assert: mimeType class = WAFullMimeTypeMatch.
	
	mimeType := WAMimeTypeMatch fromMimeType: (WAMimeType fromString: 'application/*').
	self assert: mimeType class = WAMainMimeTypeMatch.
	
	mimeType := WAMimeTypeMatch fromMimeType: (WAMimeType fromString: '*/xml').
	self assert: mimeType class = WASubMimeTypeMatch.
	
	mimeType := WAMimeTypeMatch fromMimeType: (WAMimeType fromString: '*/*').
	self assert: mimeType class = WAWildcardMimeTypeMatch! !

TestCase subclass: #WAPlaceholderParameterTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-REST-Core'!

!WAPlaceholderParameterTest methodsFor: 'testing' stamp: 'pmm 6/13/2010 09:57'!
testInstantiation
	| match |
	match := WAParameterMatch name: 'rev' value: '{1}' arguments: #().
	self assert: (match isKindOf: WAPlaceholderParameterMatch).
	self assert: match index = 1! !

!WAPlaceholderParameterTest methodsFor: 'testing' stamp: 'pmm 6/13/2010 09:52'!
testMatches
	| match |
	match := WAParameterMatch name: 'rev' value: '{1}' arguments: #().
	self assert: (match matchesName: 'rev' value: '58692').
	self assert: (match matchesName: 'rev' value: 'a').
	self deny: (match matchesName: 'revision' value: '58692').! !

!WAPlaceholderParameterTest methodsFor: 'testing' stamp: 'pmm 6/13/2010 09:54'!
testNamedInstantiation
	| match |
	match := WAParameterMatch name: 'rev' value: '{put}' arguments: #('post' 'put' 'get').
	self assert: (match isKindOf: WAPlaceholderParameterMatch).
	self assert: match index = 2! !

TestCase subclass: #WAPlaceholderPathMatchTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-REST-Core'!

!WAPlaceholderPathMatchTest methodsFor: 'testing' stamp: 'pmm 6/26/2010 17:48'!
testFullInstantiation
	| match |
	match := WAPPathMatch fromString: '{7}' index: 2 arguments: #().
	self assert: (match isKindOf: WAFullPlaceholderPathMatch).
	self assert: match priority = 1.
	self assert: match sourceIndex = 2.
	self assert: match targetIndex = 7.! !

!WAPlaceholderPathMatchTest methodsFor: 'testing' stamp: 'pmm 6/30/2010 07:38'!
testFullMapArgumentsWithElementsInto
	| match result |
	match := WAPPathMatch fromString: '{1}' index: 1 arguments: #().
	result := Array new: 1.
	match mapArgumentsWithElements: #('foo') into: result.
	self assert: result first = 'foo'! !

!WAPlaceholderPathMatchTest methodsFor: 'testing' stamp: 'pmm 6/26/2010 17:49'!
testMatchesFull
	| match |
	match := WAPPathMatch fromString: '{7}' index: 1 arguments: #().
	self assert: (match matches: 'foo')! !

!WAPlaceholderPathMatchTest methodsFor: 'testing' stamp: 'pmm 6/26/2010 17:51'!
testMatchesPrefix
	| match |
	match := WAPPathMatch fromString: 'foo.{7}' index: 1 arguments: #().
	self assert: (match matches: 'foo.bar').
	self deny: (match matches: 'foo.').
	self deny: (match matches: 'fo.bar').
	self deny: (match matches: 'oo.bar').! !

!WAPlaceholderPathMatchTest methodsFor: 'testing' stamp: 'pmm 6/26/2010 17:50'!
testMatchesSuffix
	| match |
	match := WAPPathMatch fromString: '{7}.bar' index: 1 arguments: #().
	self assert: (match matches: 'foo.bar').
	self deny: (match matches: '.bar').
	self deny: (match matches: 'foo.barz').
	self deny: (match matches: 'foo.ba').! !

!WAPlaceholderPathMatchTest methodsFor: 'testing' stamp: 'pmm 6/26/2010 17:48'!
testNamedInstantiation
	| match |
	match := WAPPathMatch fromString: '{put}' index: 2 arguments: #('get' 'put' 'post').
	self assert: (match isKindOf: WAFullPlaceholderPathMatch).
	self assert: match priority = 1.
	self assert: match sourceIndex = 2.
	self assert: match targetIndex = 2.! !

!WAPlaceholderPathMatchTest methodsFor: 'testing' stamp: 'pmm 6/29/2010 08:14'!
testPrefixInstantiation
	| match |
	match := WAPPathMatch fromString: 'foo.{787}' index: 2 arguments: #().
	self assert: (match isKindOf: WAPrefixPlaceholderPathMatch).
	self assert: match priority = 2.
	self assert: match sourceIndex = 2.
	self assert: match targetIndex = 787.! !

!WAPlaceholderPathMatchTest methodsFor: 'testing' stamp: 'pmm 6/30/2010 07:38'!
testPrefixMapArgumentsWithElementsInto
	| match result |
	match := WAPPathMatch fromString: 'foo.{1}' index: 1 arguments: #().
	result := Array new: 1.
	match mapArgumentsWithElements: #('foo.bar') into: result.
	self assert: result first = 'bar'! !

!WAPlaceholderPathMatchTest methodsFor: 'testing' stamp: 'pmm 6/29/2010 08:14'!
testSuffixInstantiation
	| match |
	match := WAPPathMatch fromString: '{787}.bar' index: 2 arguments: #().
	self assert: (match isKindOf: WASuffixPlaceholderPathMatch).
	self assert: match priority = 2.
	self assert: match sourceIndex = 2.
	self assert: match targetIndex = 787.! !

!WAPlaceholderPathMatchTest methodsFor: 'testing' stamp: 'pmm 6/30/2010 07:38'!
testSuffixMapArgumentsWithElementsInto
	| match result |
	match := WAPPathMatch fromString: '{1}.bar' index: 1 arguments: #().
	result := Array new: 1.
	match mapArgumentsWithElements: #('foo.bar') into: result.
	self assert: result first = 'foo'! !

TestCase subclass: #WAPragmaBasedRestfulHandlerTest
	instanceVariableNames: 'handler'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-REST-Core'!

!WAPragmaBasedRestfulHandlerTest methodsFor: 'running' stamp: 'pmm 5/31/2010 20:32'!
setUp
	handler := WAPragmaStubHandler new! !

!WAPragmaBasedRestfulHandlerTest methodsFor: 'testing' stamp: 'pmm 5/31/2010 20:32'!
testCreateRoutes
	self assert: handler notNil! !

TestCase subclass: #WAPragmaBasedRouteBuilderTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-REST-Core'!

!WAPragmaBasedRouteBuilderTest methodsFor: 'private' stamp: 'pmm 8/8/2010 11:03'!
assert: aCollection containsExpectionWithPath: anArray
	| found |
	found := false.
	aCollection do: [ :each |
		each size = 4 ifTrue: [
			each first = anArray first ifTrue: [
				self assert: each second = anArray second.
				self assert: each third = anArray third.
				"VW Collection >> #= hack"
				self assert: each fourth size = anArray fourth size.
				1 to: each fourth size do: [ :index |
					self assert: (each fourth at: index) = (anArray fourth at: index)].
				found := true ] ] ].
	self assert: found! !

!WAPragmaBasedRouteBuilderTest methodsFor: 'private' stamp: 'pmm 8/8/2010 10:59'!
assert: aCollection containsExpectionWithoutPath: anArray
	| found |
	found := false.
	aCollection do: [ :each |
		each size = 2 ifTrue: [
			each first = anArray first ifTrue: [
				self assert: each second = anArray second.
				found := true ] ] ].
	self assert: found! !

!WAPragmaBasedRouteBuilderTest methodsFor: 'testing' stamp: 'pmm 8/8/2010 11:04'!
testPlatformMethods
	| values expectationsWithoutPath expectationsWithPath |
	values := OrderedCollection new.
	GRPlatform current methodsWithHttpPragmaIn: WAPragmaStubHandler do: [ :method :selector :httpMethodName :path |
		path isNil
			ifTrue: [
				values add: (Array with: selector with: httpMethodName) ]
			ifFalse: [ 
				values add: (Array with: selector with: httpMethodName with: path with: (GRPlatform current argumentNamesOf: method)) ] ].
	expectationsWithoutPath := #(
		(#createDatabase: 'PUT')
		(#createNewDocumentInDatabase: 'POST')
		(#deleteDatabase: 'DELETE')
		(#getDatabase: 'GET')
		(#getInfo 'GET')).
	expectationsWithPath := #(
		(#compactDatabase: 'POST' '/{databaseName}/_compact' #('databaseName'))
		(#createBulkDocumentsInDatabase: 'POST' '/{databaseName}/_bulk_docs' #('databaseName'))
		(#createOrUpdateDocument:inDatabase: 'PUT' '/{databaseName}/{documentId}' #('documentId' 'databaseName'))
		(#deleteDocument:inDatabase: 'DELETE' '/{databaseName}/{documentId}' #('documentId' 'databaseName'))
		(#getAllDatabases 'GET' '/_all_dbs' #())
		(#getAllDocuments: 'GET' '/{databaseName}/_all_docs' #(databaseName))
		(#getConfig 'GET' '/_config' #())
		(#getDocument:ofDatabase: 'GET' '/{databaseName}/{documentId}' #('documentId' 'databaseName'))
		(#getStats 'GET' '/_stats' #())
		(#getUuids: 'GET' '/_uuids?count={numberOfUuids}' #('numberOfUuids'))
		(#getView:inDesign:inDatabase: 'GET' '/{databaseName}/_design/{designName}/_view/{viewName}' #('viewName' 'designName' 'databaseName'))
		(#queryDatabase: 'POST' '/{databaseName}/_temp_view' #('databaseName'))
		(#replicate 'POST' '/_replicate' #())).
	self assert: values size = (expectationsWithoutPath size + expectationsWithPath size).
	expectationsWithoutPath do: [ :each |
		self  assert: values containsExpectionWithoutPath: each ].
	expectationsWithPath do: [ :each |
		self  assert: values containsExpectionWithPath: each ]! !

TestCase subclass: #WARouteTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-REST-Core'!

!WARouteTest methodsFor: 'testing' stamp: 'pmm 9/8/2009 22:26'!
testCount
	| route |
	route := WARoute get: #listDatabases.
	self assert: route pathElementCount isZero.
	
	route := WARoute get: #getDatabase:.
	self assert: route pathElementCount = 1.
	
	route := WARoute get: #getDatabase:document:.
	self assert: route pathElementCount = 2! !

!WARouteTest methodsFor: 'testing' stamp: 'pmm 9/8/2009 22:19'!
testMethod
	| route |
	route := WARoute get: #listDatabases.
	self assert: route method = 'GET'.
	
	route := WARoute post: #createDatabase:document:.
	self assert: route method = 'POST'.
	
	route := WARoute copy: #copyDatabase:document:.
	self assert: route method = 'COPY'! !

!WARouteTest methodsFor: 'testing' stamp: 'pmm 9/8/2009 22:20'!
testSendSelectorWithTo
	| route victim result |
	victim := WARouteVictimMock new.
	route := WARoute get: #nothing.
	result := route sendSelectorWith: Array new to: victim.
	self assert: result = Array new.
	
	route := WARoute get: #first:.
	result := route sendSelectorWith: #('terrorists') to: victim.
	self assert: result = #('terrorists').
	
	route := WARoute get: #first:second:.
	result := route sendSelectorWith: #('terrorists' 'marschall') to: victim.
	self assert: result = #('terrorists' 'marschall').! !

TestCase subclass: #WASimpleRouteTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-REST-Core'!

!WASimpleRouteTest methodsFor: 'testing' stamp: 'pmm 9/8/2009 17:17'!
testParameterMatching
	| route parameters |
	route := WARoute get: #a:.
	self assert: (route matchesParameters: Dictionary new).
	parameters := Dictionary new at: 'key' put: 'value'; yourself.
	self deny: (route matchesParameters: parameters)! !

!WASimpleRouteTest methodsFor: 'testing' stamp: 'pmm 9/8/2009 13:01'!
testPathMatching
	| route |
	route := WARoute get: #a:.
	self deny: (route matchesPath: Array new).
	self assert: (route matchesPath: #('something')).
	self deny: (route matchesPath: #('something' 'else')).
	self assert: (route priority = 1).
	
	route := WARoute get: #a:b:.
	self deny: (route matchesPath: Array new).
	self deny: (route matchesPath: #('something')).
	self assert: (route matchesPath: #('something' 'else')).
	self deny: (route matchesPath: #('something' 'else' 'more')).
	self assert: (route priority = 2)! !

TestCase subclass: #WASubMimeTypeMatchTest
	instanceVariableNames: 'match'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-REST-Core'!

!WASubMimeTypeMatchTest methodsFor: 'running' stamp: 'pmm 10/6/2010 12:46'!
setUp
	match := WASubMimeTypeMatch sub: 'xml'! !

!WASubMimeTypeMatchTest methodsFor: 'testing' stamp: 'pmm 10/6/2010 12:46'!
testMatches
	self assert: (match matches: (WAMimeType main: 'application' sub: 'xml')).
	self assert: (match matches: (WAMimeType main: 'something' sub: 'xml')).
	self deny: (match matches: (WAMimeType main: 'application' sub: 'something')).
	self deny: (match matches: (WAMimeType main: 'something' sub: 'something')).
	
	self assert: (match matches: (WAMimeType main: '*' sub: 'xml')).
	self assert: (match matches: (WAMimeType main: 'application' sub: '*')).
	self assert: (match matches: (WAMimeType main: '*' sub: '*')).
	
	self assert: (match matches: (WAMimeType main: 'something' sub: '*')).
	self deny: (match matches: (WAMimeType main: '*' sub: 'something'))! !

!WASubMimeTypeMatchTest methodsFor: 'testing' stamp: 'pmm 10/6/2010 12:46'!
testPriority
	self assert: match priority = 2! !

TestCase subclass: #WAWildcardMimeTypeMatchTest
	instanceVariableNames: 'match'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-REST-Core'!

!WAWildcardMimeTypeMatchTest methodsFor: 'running' stamp: 'pmm 10/6/2010 12:46'!
setUp
	match := WAWildcardMimeTypeMatch new! !

!WAWildcardMimeTypeMatchTest methodsFor: 'testing' stamp: 'pmm 10/6/2010 12:46'!
testMatches
	self assert: (match matches: (WAMimeType main: 'application' sub: 'xml')).
	self assert: (match matches: (WAMimeType main: 'something' sub: 'xml')).
	self assert: (match matches: (WAMimeType main: 'application' sub: 'something')).
	self assert: (match matches: (WAMimeType main: 'something' sub: 'something')).
	
	self assert: (match matches: (WAMimeType main: '*' sub: 'xml')).
	self assert: (match matches: (WAMimeType main: 'application' sub: '*')).
	self assert: (match matches: (WAMimeType main: '*' sub: '*'))! !

!WAWildcardMimeTypeMatchTest methodsFor: 'testing' stamp: 'pmm 10/6/2010 12:46'!
testPriority
	self assert: match priority = 1! !

WAContextTest subclass: #WARestfulHandlerTest
	instanceVariableNames: 'handler'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-REST-Core'!

!WARestfulHandlerTest methodsFor: 'testing' stamp: 'pmm 9/8/2009 22:21'!
setUp
	super setUp.
	handler := WAStubHandler new! !

!WARestfulHandlerTest methodsFor: 'testing' stamp: 'pmm 9/8/2009 22:25'!
testFindRouteForMethodConsumerIfAbsent
	| route result |
	result := handler
		routeForMethod: 'GET'
		consumer: (WAPathConsumer path: #('users' 'marschall') asOrderedCollection)
		parameters: Dictionary new
		ifAbsent: [ self assert: false ].
	route := result route.
	self assert: route method = 'GET'.
	self assert: route pathElementCount = 2.
	self assert: route selector = #getDatabase:document:.
	self assert: result elements = #('users' 'marschall')! !

WARestfulHandler subclass: #WAStubHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-REST-Core'!

!WAStubHandler methodsFor: 'private' stamp: 'pmm 9/6/2009 23:51'!
createRoutes
	^OrderedCollection new
		"GET"
		add: (WARoute get: #listDatabases);
		add: (WARoute post: #createDatabase:);
		add: (WARoute post: #createDatabase:document:);
		add: (WARoute get: #getDatabase:document:);
		add: (WARoute delete: #deleteDatabase:document:);
		yourself! !

!GRPackage class methodsFor: '*seaside-tests-rest-core' stamp: 'pmm 8/8/2010 11:20'!
seasideTestsRestCore
	^ self new
		name: 'Seaside-Tests-REST-Core';
		description: 'Unit tests for the package Seaside-REST-Core.';
		addDependency: 'Seaside-REST-Core';
		url: #seasideAddonsUrl;
		yourself! !

WAPragmaBasedRestfulHandler subclass: #WAPragmaStubHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-REST-Core'!

!WAPragmaStubHandler methodsFor: 'public-database' stamp: 'pmm 6/13/2010 09:58'!
compactDatabase: databaseName
	<POST>
	<Path: '/{databaseName}/_compact'>! !

!WAPragmaStubHandler methodsFor: 'public-documents' stamp: 'pmm 6/13/2010 09:59'!
createBulkDocumentsInDatabase: databaseName
	<POST>
	<Path: '/{databaseName}/_bulk_docs'>! !

!WAPragmaStubHandler methodsFor: 'public-database' stamp: 'pmm 5/30/2010 20:10'!
createDatabase: databaseName
	<PUT>! !

!WAPragmaStubHandler methodsFor: 'public-documents' stamp: 'pmm 5/30/2010 20:13'!
createNewDocumentInDatabase: databaseName
	<POST>! !

!WAPragmaStubHandler methodsFor: 'public-documents' stamp: 'pmm 6/13/2010 09:59'!
createOrUpdateDocument: documentId inDatabase: databaseName
	<PUT>
	<Path: '/{databaseName}/{documentId}'>! !

!WAPragmaStubHandler methodsFor: 'public-database' stamp: 'pmm 5/30/2010 20:10'!
deleteDatabase: databaseName
	<DELETE>! !

!WAPragmaStubHandler methodsFor: 'public-documents' stamp: 'pmm 6/13/2010 09:59'!
deleteDocument: documentId inDatabase: databaseName
	<DELETE>
	<Path: '/{databaseName}/{documentId}'>! !

!WAPragmaStubHandler methodsFor: 'public-meta' stamp: 'pmm 5/30/2010 20:00'!
getAllDatabases
	<GET>
	<Path: '/_all_dbs'>! !

!WAPragmaStubHandler methodsFor: 'public-documents' stamp: 'pmm 6/13/2010 10:00'!
getAllDocuments: databaseName
	<GET>
	<Path: '/{databaseName}/_all_docs'>! !

!WAPragmaStubHandler methodsFor: 'public-meta' stamp: 'pmm 5/30/2010 20:02'!
getConfig
	<GET>
	<Path: '/_config'>! !

!WAPragmaStubHandler methodsFor: 'public-database' stamp: 'pmm 5/30/2010 20:11'!
getDatabase: databaseName
	<GET>! !

!WAPragmaStubHandler methodsFor: 'public-documents' stamp: 'pmm 6/13/2010 10:00'!
getDocument: documentId ofDatabase: databaseName
	<GET>
	<Path: '/{databaseName}/{documentId}'>! !

!WAPragmaStubHandler methodsFor: 'public-meta' stamp: 'pmm 5/30/2010 20:00'!
getInfo
	<GET>! !

!WAPragmaStubHandler methodsFor: 'public-meta' stamp: 'pmm 5/30/2010 20:02'!
getStats
	<GET>
	<Path: '/_stats'>! !

!WAPragmaStubHandler methodsFor: 'public-meta' stamp: 'pmm 6/13/2010 10:01'!
getUuids: numberOfUuids
	<GET>
	<Path: '/_uuids?count={numberOfUuids}'>! !

!WAPragmaStubHandler methodsFor: 'public-documents' stamp: 'pmm 6/13/2010 10:05'!
getView: viewName inDesign: designName inDatabase: databaseName
	<GET>
	<Path: '/{databaseName}/_design/{designName}/_view/{viewName}'>! !

!WAPragmaStubHandler methodsFor: 'public-documents' stamp: 'pmm 6/13/2010 10:00'!
queryDatabase: databaseName
	<POST>
	<Path: '/{databaseName}/_temp_view'>! !

!WAPragmaStubHandler methodsFor: 'public-meta' stamp: 'pmm 5/30/2010 20:09'!
replicate
	<POST>
	<Path: '/_replicate'>! !

Object subclass: #WAByMethodRoutesStub
	instanceVariableNames: 'selector arguments'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-REST-Core'!

!WAByMethodRoutesStub methodsFor: 'accessing' stamp: 'pmm 9/9/2009 18:59'!
arguments
	^ arguments! !

!WAByMethodRoutesStub methodsFor: 'stubs' stamp: 'pmm 9/9/2009 19:01'!
compactDatabase: aString
	selector := #compactDatabase:.
	arguments := Array with: aString! !

!WAByMethodRoutesStub methodsFor: 'stubs' stamp: 'pmm 9/9/2009 19:03'!
createBulkDocumentsInDatabase: aString
	selector := #createBulkDocumentsInDatabase:.
	arguments := Array with: aString! !

!WAByMethodRoutesStub methodsFor: 'stubs' stamp: 'pmm 9/9/2009 19:01'!
createDatabase: aString
	selector := #createDatabase:.
	arguments := Array with: aString! !

!WAByMethodRoutesStub methodsFor: 'stubs' stamp: 'pmm 9/9/2009 19:02'!
createNewDocumentInDatabase: aString
	selector := #createNewDocumentInDatabase:.
	arguments := Array with: aString! !

!WAByMethodRoutesStub methodsFor: 'stubs' stamp: 'pmm 9/9/2009 19:55'!
createOrUpdateDocument: aFirstString inDatabase: aSecondString
	selector := #createOrUpdateDocument:inDatabase:.
	arguments := Array with: aFirstString with: aSecondString! !

!WAByMethodRoutesStub methodsFor: 'stubs' stamp: 'pmm 9/9/2009 19:01'!
deleteDatabase: aString
	selector := #deleteDatabase:.
	arguments := Array with: aString! !

!WAByMethodRoutesStub methodsFor: 'stubs' stamp: 'pmm 9/9/2009 19:03'!
deleteDocument: aFirstString inDatabase: aSecondString
	selector := #deleteDocument:inDatabase:.
	arguments := Array with: aFirstString with: aSecondString! !

!WAByMethodRoutesStub methodsFor: 'stubs' stamp: 'pmm 9/9/2009 19:00'!
getAllDatabases
	selector := #getAllDatabases.
	arguments := Array new! !

!WAByMethodRoutesStub methodsFor: 'stubs' stamp: 'pmm 9/9/2009 19:02'!
getAllDocuments: aString
	selector := #getAllDocuments:.
	arguments := Array with: aString! !

!WAByMethodRoutesStub methodsFor: 'stubs' stamp: 'pmm 9/9/2009 19:00'!
getConfig
	selector := #getConfig.
	arguments := Array new! !

!WAByMethodRoutesStub methodsFor: 'stubs' stamp: 'pmm 9/9/2009 19:02'!
getDatabase: aString
	selector := #getDatabase:.
	arguments := Array with: aString! !

!WAByMethodRoutesStub methodsFor: 'stubs' stamp: 'pmm 9/9/2009 19:02'!
getDocument: aFirstString ofDatabase: aSecondString
	selector := #getDocument:ofDatabase:.
	arguments := Array with: aFirstString with: aSecondString! !

!WAByMethodRoutesStub methodsFor: 'stubs' stamp: 'pmm 9/9/2009 19:00'!
getInfo
	selector := #getInfo.
	arguments := Array new! !

!WAByMethodRoutesStub methodsFor: 'stubs' stamp: 'pmm 9/9/2009 19:01'!
getStats
	selector := #getStats.
	arguments := Array new! !

!WAByMethodRoutesStub methodsFor: 'stubs' stamp: 'pmm 9/9/2009 19:01'!
getUuids: aString
	selector := #getUuids:.
	arguments := Array with: aString! !

!WAByMethodRoutesStub methodsFor: 'stubs' stamp: 'pmm 9/9/2009 19:04'!
getView: aFirstString inDesign: aSecondString inDatabase: aThirdString
	selector := #getView:inDesign:inDatabase:.
	arguments := Array with: aFirstString with: aSecondString with: aThirdString! !

!WAByMethodRoutesStub methodsFor: 'stubs' stamp: 'pmm 9/9/2009 19:03'!
queryDatabase: aString
	selector := #queryDatabase:.
	arguments := Array with: aString! !

!WAByMethodRoutesStub methodsFor: 'stubs' stamp: 'pmm 9/9/2009 19:01'!
replicate
	selector := #replicate.
	arguments := Array new! !

!WAByMethodRoutesStub methodsFor: 'accessing' stamp: 'pmm 9/9/2009 18:59'!
selector
	^ selector! !

Object subclass: #WARouteVictimMock
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-REST-Core'!

!WARouteVictimMock methodsFor: 'accessing' stamp: 'pmm 9/2/2009 09:31'!
first: anObject
	^ Array with: anObject! !

!WARouteVictimMock methodsFor: 'accessing' stamp: 'pmm 9/2/2009 09:31'!
first: anFirstObject second: aSecondObject
	^ Array with: anFirstObject with: aSecondObject! !

!WARouteVictimMock methodsFor: 'accessing' stamp: 'pmm 9/2/2009 09:31'!
first: anFirstObject second: aSecondObject third: aThirdObject
	^ Array with: anFirstObject with: aSecondObject with: aThirdObject! !

!WARouteVictimMock methodsFor: 'accessing' stamp: 'pmm 9/2/2009 09:34'!
nothing
	^ Array new! !
